@@ -29,6 +29,7 @@
 #include "mainwindow.h"
 #include "stationslistdialog.h"
 #include "bookmarklistdialog.h"
+#include "pluginsdialog.h"
 #include "mapdialog.h"
 #include "settings.h"
 
@@ -37,6 +38,10 @@ MainWindow::MainWindow(QWidget *parent)
 {
   setupUi(this);
 
+  plugin = NULL;
+#ifdef HAVE_QT_LOCATION
+  localisation = NULL;
+#endif
 #ifdef Q_WS_MAEMO_5
   menu_File->removeAction(quitAction);
   menu_Help->removeAction(aboutQtAction);
@@ -54,7 +59,7 @@ MainWindow::MainWindow(QWidget *parent)
   plugin = NULL;
 
   createActions();
-  createCombo();
+  createButton();
 
   QTimer::singleShot(0, this, SLOT(delayedInit()));
 }
@@ -65,7 +70,7 @@ MainWindow::~MainWindow()
 }
 
 void
-MainWindow::createCombo()
+MainWindow::createButton()
 {
   Settings conf;
   QString selected = conf.value("StationsPlugin").toString();
@@ -73,16 +78,12 @@ MainWindow::createCombo()
 
   manager = new StationsPluginManager(this);
 
-  foreach(StationsPlugin *plugin, manager->stations()) {
-    stationsComboBox->addItem(plugin->bikeIcon(), plugin->name(),
-			      qVariantFromValue((void *) plugin));
-
+  foreach(StationsPlugin *plugin, manager->stations().values()) {
     if (plugin->id() == selected)
       selectedPlugin = plugin;
   }
-
   setStationsPlugin(selectedPlugin);
-  connect(stationsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(comboIndexChanged(int)));
+  connect(pushButton, SIGNAL(clicked(bool)), this, SLOT(buttonClicked()));
 }
 
 void
@@ -109,6 +110,7 @@ MainWindow::delayedInit()
   QNetworkSession* session = new QNetworkSession(ap);
 
   session->open();
+
   if (!session->waitForOpened(-1)) {
     QMessageBox::critical(this, tr("Network Error"), session->errorString());
     QApplication::instance()->quit();
@@ -126,7 +128,8 @@ MainWindow::delayedInit()
   connect(localisation, SIGNAL(positionUpdated(QGeoPositionInfo)),
 	  this, SLOT(positionUpdated(QGeoPositionInfo)));
   connect(localisation, SIGNAL(requestTimeout()), this, SLOT(positionRequestTimeout()));
-  localisation->setUpdateInterval(30000);
+
+  localisation->setUpdateInterval(5000);
   localisation->startUpdates();
   localisation->requestUpdate(15000);
 #endif
@@ -151,42 +154,37 @@ MainWindow::positionUpdated(QGeoPositionInfo info)
     statusMsg(tr("Got GPS Fix."));
   position = info;
 
-  foreach (StationsPlugin *plugin, manager->stations()) {
-    if (plugin->rect().contains(QPointF(coord.latitude(), coord.longitude()))) {
-      setStationsPlugin(plugin);
-      break;
-    }
-  }
+  QPointF pt(coord.latitude(), coord.longitude());
+
+  if (plugin && plugin->rect().contains(pt))
+    return ;
+
+  foreach (StationsPlugin *plugin, manager->stations().values())
+    if (plugin->rect().contains(pt))
+      return setStationsPlugin(plugin);
 }
 #endif
 
 void
-MainWindow::comboIndexChanged(int index)
+MainWindow::buttonClicked()
 {
-  QVariant data = stationsComboBox->itemData(index);
-  StationsPlugin *plugin = (StationsPlugin *)data.value<void *>();
+  PluginsDialog dlg(manager, this);
 
-  if (plugin) {
-    Settings conf;
-
-    setStationsPlugin(plugin);
-    conf.setValue("StationsPlugin", plugin->id());
-  }
+  dlg.exec();
+  setStationsPlugin(dlg.plugin(), true);
 }
 
 void
-MainWindow::setStationsPlugin(StationsPlugin *sta)
+MainWindow::setStationsPlugin(StationsPlugin *sta, bool save)
 {
-  if (!sta || plugin == sta)
-    return ;
-
   plugin = sta;
-
-  for (int i = 0; i < stationsComboBox->count(); ++i) {
-    QVariant data = stationsComboBox->itemData(i);
-
-    if (plugin == (StationsPlugin *)data.value<void *>())
-      stationsComboBox->setCurrentIndex(i);
+  if (plugin) {
+    pushButton->setText(plugin->name());
+    pushButton->setIcon(plugin->bikeIcon());
+  }
+  if (save) {
+    Settings conf;
+    conf.setValue("StationsPlugin", plugin ? plugin->id() : "auto");
   }
 }
 
@@ -197,6 +195,7 @@ MainWindow::about()
 		     tr("Version: " LUGDULOV_VERSION "\n"
 			"Home: http://xf.iksaif.net/dev/lugdulov.html\n\n"
 			"Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>\n"
+			"Copyright (C) 2010 Patrick Installé <PatrickInstalle@P-Installe.be>\n"
 			"\n"
 			"This program is free software; you can redistribute it and/or modify\n"
 			"it under the terms of the GNU General Public License as published by\n"
@@ -275,6 +274,7 @@ MainWindow::map()
     }
   }
 #endif
+
   if (zoom)
     map->centerView(pt, zoom);
   showAndDelete(map);
@@ -308,5 +308,6 @@ MainWindow::chooseStationsPlugin()
   QMessageBox::warning(this, tr("Please set Location."),
 		       tr("We can't guess your current location, "
 			  "please choose one in the list."));
-  stationsComboBox->showPopup();
+
+  buttonClicked();
 }
