@@ -45,8 +45,6 @@ MapWidget::MapWidget(QWidget *parent)
   statusTimer->setInterval(60000);
   connect(statusTimer, SIGNAL(timeout()), this, SLOT(refreshStatus()));
   statusTimer->start();
-
-  ImageManager::instance()->abortLoading(); // Don't load south pole images
 }
 
 MapWidget::~MapWidget()
@@ -102,9 +100,9 @@ MapWidget::setupMapControl()
 
   Layer* l = new Layer("Custom Layer", mapadapter, Layer::MapLayer);
 
+  mc->enablePersistentCache();
   mc->addLayer(l);
   mc->showScale(true);
-  mc->enablePersistentCache();
 
   stationsLayer = new GeometryLayer("Stations", mapadapter);
   mc->addLayer(stationsLayer);
@@ -148,8 +146,11 @@ MapWidget::setPlugin(StationsPlugin *p)
 
   connect(model, SIGNAL(dataChanged(const QModelIndex &, const QModelIndex &)),
 	  this, SLOT(dataChanged(const QModelIndex &, const QModelIndex &)));
+  connect(model, SIGNAL(rowsInserted(const QModelIndex &, int, int)),
+	  this, SLOT(refreshStations()));
 
-  plugin->fetchAll();
+  plugin->fetchAll(); // First fetch cached data
+  QTimer::singleShot(200, plugin, SLOT(fetchOnline())); // Then load online data
 }
 
 #ifdef HAVE_QT_LOCATION
@@ -198,15 +199,42 @@ MapWidget::geometryClicked(Geometry *geom, QPoint pt)
 void
 MapWidget::showStation(Station *station)
 {
-  if (geometries.find(station) != geometries.end())
+  if (geometries.find(station) == geometries.end()) {
+    QPixmap *pix = new QPixmap(station->plugin()->bikeIcon().pixmap(QSize(48, 48)));
+    Point *geom = new Point(station->pos().y(), station->pos().x(), pix, station->name());
+
+    stationsLayer->addGeometry(geom);
+    stations[geom] = station;
+    geometries[station] = geom;
+  }
+
+  QPainter painter(geometries[station]->pixmap());
+  QRectF rect1, rect2;
+
+  rect1 = rect2 = QRectF(10, 0, 30, 3);
+
+  painter.setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform);
+  painter.setPen(Qt::NoPen);
+  if (station->bikes() > 0 && station->totalSlots() > 0) {
+    rect1.setWidth(rect1.width() * (double)station->bikes() / (double)station->totalSlots());
+    rect2.setWidth(rect2.width() * (double)station->freeSlots() / (double)station->totalSlots());
+    rect2.moveTo(rect1.x() + rect1.width(), rect2.y());
+  } else if (station->bikes() > 0) {
+    rect2 = QRectF();
+  } else if (station->freeSlots() > 0) {
+    rect1 = QRectF();
+  } else {
     return ;
+  }
 
-  QPixmap *pix = new QPixmap(station->plugin()->bikeIcon().pixmap(QSize(48, 48)));
-  Point *geom = new Point(station->pos().y(), station->pos().x(), pix, station->name());
-
-  stationsLayer->addGeometry(geom);
-  stations[geom] = station;
-  geometries[station] = geom;
+  if (!rect1.isNull()) {
+    painter.setBrush(Qt::darkGreen);
+    painter.drawRect(rect1);
+  }
+  if (!rect2.isNull()) {
+    painter.setBrush(Qt::darkRed);
+    painter.drawRect(rect2);
+  }
 }
 
 void
@@ -232,7 +260,6 @@ MapWidget::refreshStations()
 void
 MapWidget::refreshStatus()
 {
-  return ; /* Not needed right now, only here for future usage */
   foreach (Point *geometry, stations.keys()) {
     if (mc->getViewport().contains(geometry->coordinate()))
       stations[geometry]->plugin()->updateCached(stations[geometry]);
@@ -242,7 +269,13 @@ MapWidget::refreshStatus()
 void
 MapWidget::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
 {
-  //qDebug() << "dataChanged" << topLeft.row() << bottomRight.row();
+  for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
+    Station *station = (Station *)model->index(i, 0).data(StationsModel::StationRole).value<void *>();
+
+    if (geometries.find(station) != geometries.end())
+      showStation(station);
+  }
+  mc->updateRequestNew();
 }
 
 void
@@ -254,7 +287,7 @@ MapWidget::centerView(const QPointF & pt, int zoom)
   if (zoom != -1)
     mc->setZoom(zoom);
 
-  refreshStations();
+  stationsTimer->start();
 }
 
 void
