@@ -77,7 +77,8 @@ StationsListDialog::StationsListDialog(StationsPlugin *plugin, QWidget *parent)
   connect(plugin, SIGNAL(error(const QString &, const QString &)),
 	  this, SLOT(error(const QString &, const QString &)));
 
-  QTimer::singleShot(1, plugin, SLOT(fetchAll()));
+  QTimer::singleShot(1, plugin, SLOT(fetchAll())); // First fetch cached data
+  QTimer::singleShot(200, plugin, SLOT(fetchOnline())); // Then load online data
 }
 
 StationsListDialog::~StationsListDialog()
