@@ -19,14 +19,14 @@
 #ifndef STATIONS_CERGYPONTOISE_H
 #define STATIONS_CERGYPONTOISE_H
 
-#include "stationsplugincarto.h"
+#include "stationsplugincyclocity.h"
 
-class StationsPluginCergyPontoise : public StationsPluginCarto
+class StationsPluginCergypontoise : public StationsPluginCycloCity
 {
   Q_OBJECT
  public:
-  StationsPluginCergyPontoise(QObject *parent);
-  ~StationsPluginCergyPontoise();
+  StationsPluginCergypontoise(QObject *parent);
+  ~StationsPluginCergypontoise();
 
   QString id() const;
   QString name() const;
@@ -35,3 +35,4 @@ class StationsPluginCergyPontoise : public StationsPluginCarto
 };
 
 #endif /* STATIONS_CERGYPONTOISE_H */
+
