@@ -23,9 +23,9 @@
 #include "nantes_p.h"
 
 StationsPluginNantes::StationsPluginNantes(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateNantes();
+  d = new StationsPluginSimplePrivateNantes();
 }
 
 StationsPluginNantes::~StationsPluginNantes()
