@@ -23,9 +23,9 @@
 #include "rouen_p.h"
 
 StationsPluginRouen::StationsPluginRouen(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateRouen();
+  d = new StationsPluginSimplePrivateRouen();
 }
 
 StationsPluginRouen::~StationsPluginRouen()
