@@ -23,9 +23,9 @@
 #include "toulouse_p.h"
 
 StationsPluginToulouse::StationsPluginToulouse(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateToulouse();
+  d = new StationsPluginSimplePrivateToulouse();
 }
 
 StationsPluginToulouse::~StationsPluginToulouse()
