@@ -23,9 +23,9 @@
 #include "dublin_p.h"
 
 StationsPluginDublin::StationsPluginDublin(QObject *parent)
-  : StationsPluginCarto(parent)
+  : StationsPluginCycloCity(parent)
 {
-  d = new StationsPluginCartoPrivateDublin();
+  d = new StationsPluginSimplePrivateDublin();
 }
 
 StationsPluginDublin::~StationsPluginDublin()
