@@ -30,15 +30,13 @@ StationsPluginFactoryLuxembourg::id() const
 QString
 StationsPluginFactoryLuxembourg::name() const
 {
-  return QString::fromUtf8("Luxembourg - Authors:"
-			   "Patrick Installé <PatrickInstalle@P-Installe.be>,"
-			   "Corentin Chary <corentin.chary@gmail.com>");
+  return QString::fromUtf8("Luxembourg");
 }
 
 QIcon
 StationsPluginFactoryLuxembourg::icon() const
 {
-  return QIcon(":/luxembourg/bike.png");
+  return QIcon(":/luxembourg/lu.png");
 }
 
 QList < StationsPlugin * >
